```
Usage: vcd vapp capture [OPTIONS] <name> <catalog> [template]

Options:
  -i, --identical         Make identical copy
  -c, --customizable      Make copy customizable during instantiation
  -d, --description TEXT  Description
  -h, --help              Show this message and exit.

```
